# emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
# vi: set ft=python sts=4 ts=4 sw=4 et:
"""
Package contains pure python neuroimaging algorithms

Examples: artifactdetect

"""
__docformat__ = "restructuredtext"
